# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.x     | :white_check_mark: |
| <2.0.0  | :x:                |

## Reporting a Vulnerability

If you find a vulnerability you have two ways to report it:

- Write a dm to one of our core developers on https://pycord.dev/discord
- Write an email to admin@pycord.dev
